@@ -46,7 +46,7 @@ if [ $? -ne 0 ]; then
 fi
 
 # AttachAddon (not needed for our implementation but keeping for compatibility)
-wget "https://unpkg.com/@xterm/addon-attach@0.9.0/lib/addon-attach.js" -O addons/xterm-addon-attach.js
+wget "https://unpkg.com/xterm-addon-attach@0.9.0/lib/xterm-addon-attach.js" -O addons/xterm-addon-attach.js
 if [ $? -ne 0 ]; then
     echo "Error: Failed to download xterm-addon-attach.js"
     exit 1
