@@ -391,8 +391,8 @@ class WordPressManager {
             throw new Exception("Site not found");
         }
         
-        $container = $site['domain_name'] . '-01';
-        $user = $site['username'];
+        $container = $site['domain'] . '-01';
+        $user = $site['user'];
         $results = [
             'core' => null,
             'plugins' => null,
@@ -400,67 +400,63 @@ class WordPressManager {
             'backup_results' => null
         ];
         
-        // Update status to in_progress
-        $this->recordUpdateProgress($updateId, 'Creating backup before complete update...');
-        
         // Create backup first
         if ($site['backup_target_id']) {
             try {
                 $backupResult = $this->createBackup($siteId);
                 $results['backup_results'] = $backupResult;
-                $this->recordUpdateProgress($updateId, 'Backup created successfully');
+                // Backup created successfully
             } catch (Exception $e) {
-                $this->recordUpdateProgress($updateId, 'Backup failed: ' . $e->getMessage());
+                // Backup failed: continuing with update
                 // Continue with update even if backup fails
             }
         }
         
         // Update WordPress core
-        $this->recordUpdateProgress($updateId, 'Updating WordPress core...');
         try {
             $coreResult = $this->execWpCli($container, $user, "wp core update");
             if ($coreResult['success']) {
                 $results['core'] = ['success' => true, 'message' => 'Core updated successfully'];
-                $this->recordUpdateProgress($updateId, 'WordPress core updated successfully');
+                // WordPress core updated successfully
             } else {
                 $results['core'] = ['success' => false, 'message' => $coreResult['error']];
-                $this->recordUpdateProgress($updateId, 'Core update failed: ' . $coreResult['error']);
+                // Core update failed
             }
         } catch (Exception $e) {
             $results['core'] = ['success' => false, 'message' => $e->getMessage()];
-            $this->recordUpdateProgress($updateId, 'Core update exception: ' . $e->getMessage());
+            // Core update exception
         }
         
         // Update all plugins
-        $this->recordUpdateProgress($updateId, 'Updating plugins...');
+        // Update plugins
         try {
             $pluginResult = $this->execWpCli($container, $user, "wp plugin update --all");
             if ($pluginResult['success']) {
                 $results['plugins'] = ['success' => true, 'message' => 'Plugins updated successfully'];
-                $this->recordUpdateProgress($updateId, 'All plugins updated successfully');
+                // All plugins updated successfully
             } else {
                 $results['plugins'] = ['success' => false, 'message' => $pluginResult['error']];
-                $this->recordUpdateProgress($updateId, 'Plugin updates failed: ' . $pluginResult['error']);
+                // Plugin updates failed
             }
         } catch (Exception $e) {
             $results['plugins'] = ['success' => false, 'message' => $e->getMessage()];
-            $this->recordUpdateProgress($updateId, 'Plugin update exception: ' . $e->getMessage());
+            // Plugin update exception
         }
         
         // Update all themes
-        $this->recordUpdateProgress($updateId, 'Updating themes...');
+        // Update themes
         try {
             $themeResult = $this->execWpCli($container, $user, "wp theme update --all");
             if ($themeResult['success']) {
                 $results['themes'] = ['success' => true, 'message' => 'Themes updated successfully'];
-                $this->recordUpdateProgress($updateId, 'All themes updated successfully');
+                // All themes updated successfully
             } else {
                 $results['themes'] = ['success' => false, 'message' => $themeResult['error']];
-                $this->recordUpdateProgress($updateId, 'Theme updates failed: ' . $themeResult['error']);
+                // Theme updates failed
             }
         } catch (Exception $e) {
             $results['themes'] = ['success' => false, 'message' => $e->getMessage()];
-            $this->recordUpdateProgress($updateId, 'Theme update exception: ' . $e->getMessage());
+            // Theme update exception
         }
         
         // Get new WordPress version
@@ -476,7 +472,7 @@ class WordPressManager {
         
         // Record completion
         $this->recordUpdateComplete($updateId, $newVersion);
-        $this->recordUpdateProgress($updateId, 'Complete update finished');
+        // Complete update finished
         
         return $results;
     }
